@@ -1,7 +1,5 @@
 #include "marshalers.h"
-
-#include	<glib-object.h>
-
+#include <glib-object.h>
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -49,24 +47,23 @@
 #define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
-
 /* BOOL:UINT,UINT,UINT (./marshalers.list:1) */
 void
 bus_marshal_BOOLEAN__UINT_UINT_UINT (GClosure     *closure,
-                                     GValue       *return_value G_GNUC_UNUSED,
+                                     GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
-  typedef gboolean (*GMarshalFunc_BOOLEAN__UINT_UINT_UINT) (gpointer     data1,
-                                                            guint        arg_1,
-                                                            guint        arg_2,
-                                                            guint        arg_3,
-                                                            gpointer     data2);
-  GMarshalFunc_BOOLEAN__UINT_UINT_UINT callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef gboolean (*GMarshalFunc_BOOLEAN__UINT_UINT_UINT) (gpointer data1,
+                                                            guint arg1,
+                                                            guint arg2,
+                                                            guint arg3,
+                                                            gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__UINT_UINT_UINT callback;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -96,18 +93,18 @@ bus_marshal_BOOLEAN__UINT_UINT_UINT (GClosure     *closure,
 /* OBJECT:STRING (./marshalers.list:2) */
 void
 bus_marshal_OBJECT__STRING (GClosure     *closure,
-                            GValue       *return_value G_GNUC_UNUSED,
+                            GValue       *return_value,
                             guint         n_param_values,
                             const GValue *param_values,
                             gpointer      invocation_hint G_GNUC_UNUSED,
                             gpointer      marshal_data)
 {
-  typedef GObject* (*GMarshalFunc_OBJECT__STRING) (gpointer     data1,
-                                                   gpointer     arg_1,
-                                                   gpointer     data2);
-  GMarshalFunc_OBJECT__STRING callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef GObject* (*GMarshalFunc_OBJECT__STRING) (gpointer data1,
+                                                   gpointer arg1,
+                                                   gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_OBJECT__STRING callback;
   GObject* v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -141,13 +138,13 @@ bus_marshal_VOID__INT_UINT (GClosure     *closure,
                             gpointer      invocation_hint G_GNUC_UNUSED,
                             gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__INT_UINT) (gpointer     data1,
-                                               gint         arg_1,
-                                               guint        arg_2,
-                                               gpointer     data2);
-  GMarshalFunc_VOID__INT_UINT callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__INT_UINT) (gpointer data1,
+                                               gint arg1,
+                                               guint arg2,
+                                               gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__INT_UINT callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -178,15 +175,15 @@ bus_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
                                    gpointer      invocation_hint G_GNUC_UNUSED,
                                    gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__INT_INT_INT_INT) (gpointer     data1,
-                                                      gint         arg_1,
-                                                      gint         arg_2,
-                                                      gint         arg_3,
-                                                      gint         arg_4,
-                                                      gpointer     data2);
-  GMarshalFunc_VOID__INT_INT_INT_INT callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__INT_INT_INT_INT) (gpointer data1,
+                                                      gint arg1,
+                                                      gint arg2,
+                                                      gint arg3,
+                                                      gint arg4,
+                                                      gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT_INT_INT callback;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -211,6 +208,39 @@ bus_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
 }
 
 /* VOID:OBJECT (./marshalers.list:5) */
+void
+bus_marshal_VOID__OBJECT (GClosure     *closure,
+                          GValue       *return_value G_GNUC_UNUSED,
+                          guint         n_param_values,
+                          const GValue *param_values,
+                          gpointer      invocation_hint G_GNUC_UNUSED,
+                          gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__OBJECT) (gpointer data1,
+                                             gpointer arg1,
+                                             gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT callback;
+
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__OBJECT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_object (param_values + 1),
+            data2);
+}
 
 /* VOID:OBJECT,BOOLEAN (./marshalers.list:6) */
 void
@@ -221,13 +251,13 @@ bus_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_BOOLEAN) (gpointer     data1,
-                                                     gpointer     arg_1,
-                                                     gboolean     arg_2,
-                                                     gpointer     data2);
-  GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__OBJECT_BOOLEAN) (gpointer data1,
+                                                     gpointer arg1,
+                                                     gboolean arg2,
+                                                     gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -258,13 +288,13 @@ bus_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_STRING) (gpointer     data1,
-                                                    gpointer     arg_1,
-                                                    gpointer     arg_2,
-                                                    gpointer     data2);
-  GMarshalFunc_VOID__OBJECT_STRING callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__OBJECT_STRING) (gpointer data1,
+                                                    gpointer arg1,
+                                                    gpointer arg2,
+                                                    gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_STRING callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -295,14 +325,14 @@ bus_marshal_VOID__OBJECT_UINT_BOOLEAN (GClosure     *closure,
                                        gpointer      invocation_hint G_GNUC_UNUSED,
                                        gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN) (gpointer     data1,
-                                                          gpointer     arg_1,
-                                                          guint        arg_2,
-                                                          gboolean     arg_3,
-                                                          gpointer     data2);
-  GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN) (gpointer data1,
+                                                          gpointer arg1,
+                                                          guint arg2,
+                                                          gboolean arg3,
+                                                          gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN callback;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -334,15 +364,15 @@ bus_marshal_VOID__OBJECT_UINT_BOOLEAN_UINT (GClosure     *closure,
                                             gpointer      invocation_hint G_GNUC_UNUSED,
                                             gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN_UINT) (gpointer     data1,
-                                                               gpointer     arg_1,
-                                                               guint        arg_2,
-                                                               gboolean     arg_3,
-                                                               guint        arg_4,
-                                                               gpointer     data2);
-  GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN_UINT callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN_UINT) (gpointer data1,
+                                                               gpointer arg1,
+                                                               guint arg2,
+                                                               gboolean arg3,
+                                                               guint arg4,
+                                                               gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN_UINT callback;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -375,15 +405,15 @@ bus_marshal_VOID__OBJECT_STRING_STRING_STRING (GClosure     *closure,
                                                gpointer      invocation_hint G_GNUC_UNUSED,
                                                gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_STRING_STRING_STRING) (gpointer     data1,
-                                                                  gpointer     arg_1,
-                                                                  gpointer     arg_2,
-                                                                  gpointer     arg_3,
-                                                                  gpointer     arg_4,
-                                                                  gpointer     data2);
-  GMarshalFunc_VOID__OBJECT_STRING_STRING_STRING callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__OBJECT_STRING_STRING_STRING) (gpointer data1,
+                                                                  gpointer arg1,
+                                                                  gpointer arg2,
+                                                                  gpointer arg3,
+                                                                  gpointer arg4,
+                                                                  gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_STRING_STRING_STRING callback;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -408,6 +438,39 @@ bus_marshal_VOID__OBJECT_STRING_STRING_STRING (GClosure     *closure,
 }
 
 /* VOID:STRING (./marshalers.list:11) */
+void
+bus_marshal_VOID__STRING (GClosure     *closure,
+                          GValue       *return_value G_GNUC_UNUSED,
+                          guint         n_param_values,
+                          const GValue *param_values,
+                          gpointer      invocation_hint G_GNUC_UNUSED,
+                          gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__STRING) (gpointer data1,
+                                             gpointer arg1,
+                                             gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__STRING callback;
+
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__STRING) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            data2);
+}
 
 /* VOID:STRING,INT (./marshalers.list:12) */
 void
@@ -418,13 +481,13 @@ bus_marshal_VOID__STRING_INT (GClosure     *closure,
                               gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__STRING_INT) (gpointer     data1,
-                                                 gpointer     arg_1,
-                                                 gint         arg_2,
-                                                 gpointer     data2);
-  GMarshalFunc_VOID__STRING_INT callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__STRING_INT) (gpointer data1,
+                                                 gpointer arg1,
+                                                 gint arg2,
+                                                 gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_INT callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -455,13 +518,13 @@ bus_marshal_VOID__UINT_UINT (GClosure     *closure,
                              gpointer      invocation_hint G_GNUC_UNUSED,
                              gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__UINT_UINT) (gpointer     data1,
-                                                guint        arg_1,
-                                                guint        arg_2,
-                                                gpointer     data2);
-  GMarshalFunc_VOID__UINT_UINT callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__UINT_UINT) (gpointer data1,
+                                                guint arg1,
+                                                guint arg2,
+                                                gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_UINT callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -492,14 +555,14 @@ bus_marshal_VOID__UINT_UINT_UINT (GClosure     *closure,
                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__UINT_UINT_UINT) (gpointer     data1,
-                                                     guint        arg_1,
-                                                     guint        arg_2,
-                                                     guint        arg_3,
-                                                     gpointer     data2);
-  GMarshalFunc_VOID__UINT_UINT_UINT callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__UINT_UINT_UINT) (gpointer data1,
+                                                     guint arg1,
+                                                     guint arg2,
+                                                     guint arg3,
+                                                     gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_UINT_UINT callback;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -523,4 +586,35 @@ bus_marshal_VOID__UINT_UINT_UINT (GClosure     *closure,
 }
 
 /* VOID:VOID (./marshalers.list:15) */
+void
+bus_marshal_VOID__VOID (GClosure     *closure,
+                        GValue       *return_value G_GNUC_UNUSED,
+                        guint         n_param_values,
+                        const GValue *param_values,
+                        gpointer      invocation_hint G_GNUC_UNUSED,
+                        gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__VOID) (gpointer data1,
+                                           gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__VOID callback;
+
+  g_return_if_fail (n_param_values == 1);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__VOID) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            data2);
+}
 
